==> aptechka-0.42.5.tgz: package/lib/store/index.js <==
var x = (e) => {
  throw TypeError(e);
};
var g = (e, r, s) => r.has(e) || x("Cannot " + s);
var c = (e, r, s) => (g(e, r, "read from private field"), s ? s.call(e) : r.get(e)), i = (e, r, s) => r.has(e) ? x("Cannot add the same private member more than once") : r instanceof WeakSet ? r.add(e) : r.set(e, s), h = (e, r, s, t) => (g(e, r, "write to private field"), t ? t.call(e, s) : r.set(e, s), s);
import { S as a } from "../Store-Cm3LPXlx.js";
import { a as k, s as q } from "../Store-Cm3LPXlx.js";
import { d as y } from "../function-C10DGppn.js";
var d;
class I extends a {
  constructor(s, t, u) {
    super(null, u);
    i(this, d);
    h(this, d, s.subscribe((l) => {
      this.current = t(l.current);
    }));
  }
  close() {
    super.close(), c(this, d).call(this);
  }
}
d = new WeakMap();
var f;
class P extends a {
  constructor(s, t, u) {
    super(null, u);
    i(this, f);
    h(this, f, s.subscribe((l) => {
      this.current = l.current.map((m, v, S) => t(m, v, S));
    }));
  }
  close() {
    super.close(), c(this, f).call(this);
  }
}
f = new WeakMap();
var b, n, o;
class R extends a {
  constructor(s, t, u) {
    super(s, u);
    i(this, b);
    i(this, n);
    i(this, o, 0);
    h(this, n, new a(!1)), h(this, b, t), u != null && u.manualControl || this.refetch();
  }
  get isPending() {
    return c(this, n);
  }
  refetch() {
    c(this, n).current = !0, h(this, o, c(this, o) + 1);
    const s = c(this, o);
    c(this, b).call(this).then((t) => {
      s === c(this, o) && (c(this, n).current = !1, this.current = t);
    });
  }
}
b = new WeakMap(), n = new WeakMap(), o = new WeakMap();
var p;
class w extends a {
  constructor(s, t, u) {
    super(null, u);
    i(this, p, []);
    const l = y(() => {
      this.current = t();
    }, 0);
    s.forEach((m) => {
      c(this, p).push(
        m.subscribe(() => {
          l();
        })
      );
    });
  }
  close() {
    super.close(), c(this, p).forEach((s) => s());
  }
}
p = new WeakMap();
export {
  w as Composed,
  I as Derived,
  P as DerivedArray,
  R as Resource,
  a as Store,
  k as activeStores,
  q as storeRegistry
};

==> aptechka-0.47.11.tgz: package/lib/store/index.js <==
var x = (e) => {
  throw TypeError(e);
};
var g = (e, r, s) => r.has(e) || x("Cannot " + s);
var c = (e, r, s) => (g(e, r, "read from private field"), s ? s.call(e) : r.get(e)), i = (e, r, s) => r.has(e) ? x("Cannot add the same private member more than once") : r instanceof WeakSet ? r.add(e) : r.set(e, s), h = (e, r, s, t) => (g(e, r, "write to private field"), t ? t.call(e, s) : r.set(e, s), s);
import { S as a } from "../Store-D2xCXENW.js";
import { a as q, s as z } from "../Store-D2xCXENW.js";
import { d as y } from "../function-C10DGppn.js";
import "../index-euf5anj6.js";
var d;
class P extends a {
  constructor(s, t, u) {
    super(null, u);
    i(this, d);
    h(this, d, s.subscribe((l) => {
      this.current = t(l.current);
    }));
  }
  close() {
    super.close(), c(this, d).call(this);
  }
}
d = new WeakMap();
var f;
class R extends a {
  constructor(s, t, u) {
    super(null, u);
    i(this, f);
    h(this, f, s.subscribe((l) => {
      this.current = l.current.map((m, v, S) => t(m, v, S));
    }));
  }
  close() {
    super.close(), c(this, f).call(this);
  }
}
f = new WeakMap();
var b, n, o;
class w extends a {
  constructor(s, t, u) {
    super(s, u);
    i(this, b);
    i(this, n);
    i(this, o, 0);
    h(this, n, new a(!1)), h(this, b, t), u != null && u.manualControl || this.refetch();
  }
  get isPending() {
    return c(this, n);
  }
  refetch() {
    c(this, n).current = !0, h(this, o, c(this, o) + 1);
    const s = c(this, o);
    c(this, b).call(this).then((t) => {
      s === c(this, o) && (c(this, n).current = !1, this.current = t);
    });
  }
}
b = new WeakMap(), n = new WeakMap(), o = new WeakMap();
var p;
class A extends a {
  constructor(s, t, u) {
    super(null, u);
    i(this, p, []);
    const l = y(() => {
      this.current = t();
    }, 0);
    s.forEach((m) => {
      c(this, p).push(
        m.subscribe(() => {
          l();
        })
      );
    });
  }
  close() {
    super.close(), c(this, p).forEach((s) => s());
  }
}
p = new WeakMap();
export {
  A as Composed,
  P as Derived,
  R as DerivedArray,
  w as Resource,
  a as Store,
  q as activeStores,
  z as storeRegistry
};
